
package AbstractParserFactory;

use strict;
use warnings;
use QFCParser;

=pod 

=head1 TITLE

AbstractParserFactory

=head1 AUTHOR

paramsan

=head1 NAME

AbstractParserFactory: A class that is used to construct Parser Objects. 

=head1 SYNOPSIS

	use AbstractParser;
	use AbstractParserFactory;
	
	$qfcParser     = AbstractParserFactory->new("QFC");
	$allSpecials = $qfcParser->GetSpecials($zipCode);

=head1 REQUIRES

Perl5.10.0, QFCParser

=head1 EXPORTS

Nothing

=head1 DESCRIPTION

A class that is used to construct Parser Objects. All the objects constructed
are guranteed to implement the AbstractParser interface.

=head1 CLASS VARIABLES

None

=head1 METHODS

=head2 new

=over 4

=item Description

Construct and return a reference to a new concrete parser that actually implements the 
parser class.

=item Arguments 

B<$storeName> A string name representing the storename of which parser is requested. 
Currently only "QFC" is supported.

=item Returns

A reference to the requested parser.

If the parser with the storeName is not found, this method will die() with the error message 
"No parser implemented for store '$storeName'"

=item Usage

C<< $qfcParser = AbstractParserFactory->new("QFC"); >>

=back

=cut	

sub new {
	my $class = shift;
	my $storeName = shift;
	
	if ($storeName =~ m/^QFC$/i) {
		return QFCParser->new();
	}
	else {
		die("No parser implemented for store '$storeName'");
	}	
}

1;