
-- script_create_tables.sql creates all the necessary tables for CookingSpecial.

-- note: this file is used in scripts to automatically populate databases.
-- note: this file is consistent with the design document in trunk/docs/dev/cookingspecial_design.pdf

CREATE TABLE user (
	id int NOT NULL AUTO_INCREMENT,
	username varchar(255) NOT NULL,
	password varchar(32) NOT NULL,
	email varchar(255),
	zipCode int(11),

	PRIMARY KEY(id),
	UNIQUE(username),
	UNIQUE(email)
);

CREATE TABLE usersavedfood (
	userId int NOT NULL,
	favoriteFood varchar(50) NOT NULL,
	
	FOREIGN KEY(userId) REFERENCES user(id)
);

CREATE TABLE storechain (
	id int NOT NULL AUTO_INCREMENT,
	name varchar(25),
	websiteUrl varchar(255),

	PRIMARY KEY(id),
	UNIQUE(name)
);

CREATE TABLE storelocation (
	id int NOT NULL AUTO_INCREMENT,
	storeChainId int NOT NULL,
	address varchar(255),
	city varchar(255),
	state varchar(2),
	zipCode varchar(10),
	phone varchar(20),

	PRIMARY KEY(id),
	FOREIGN KEY(storeChainId) REFERENCES storechain(id)
);

CREATE TABLE special (
	id int NOT NULL AUTO_INCREMENT,
	storeLocationId int NOT NULL,
	title varchar(255),
	description varchar(500),
	price varchar(75),

	PRIMARY KEY(id),
	FOREIGN KEY(storeLocationId) REFERENCES storelocation(id)
);

CREATE TABLE usersavedspecial (
	userId int NOT NULL,
	specialId int NOT NULL,
	
	FOREIGN KEY(userId) REFERENCES user(id),
	FOREIGN KEY(specialId) REFERENCES special(id)
);

CREATE TABLE ingredient (
	id int NOT NULL AUTO_INCREMENT,
	name varchar(100),

	PRIMARY KEY(id),
	UNIQUE(name)
);

CREATE VIEW specialingredient AS
	select s.id as specialId, i.id as ingredientId
	from special s, ingredient i
	where s.title like concat('%', i.name, '%');

CREATE TABLE recipe (
	id int NOT NULL AUTO_INCREMENT,
	name varchar(100) NOT NULL,
	directions TEXT NOT NULL,

	PRIMARY KEY(id)
);

CREATE TABLE usersavedrecipe (
	userId int NOT NULL,
	recipeId int NOT NULL,
	
	FOREIGN KEY(userId) REFERENCES user(id),
	FOREIGN KEY(recipeId) REFERENCES recipe(id)
);

CREATE TABLE recipeingredient (
	recipeId int NOT NULL,
	ingredientId int NOT NULL,
	quantity varchar(40),
	preparation varchar(40),

	FOREIGN KEY(recipeId) REFERENCES recipe(id),
	FOREIGN KEY(ingredientId) REFERENCES ingredient(id)
);


