#!/bin/bash

# See UNITTEST.txt for specific information on individual tests.

# NOTE: unittest.sh requires
# * that you have installed CookingSpecial
# * that you are running from a standard Linux environment
# * and have an http:// address from which you can access the installation's web directory.
# 	* This web directory should be immediately accessible after building CookingSpecial.

####### BEGIN CHANGE VARIABLES #######
# The http:// address from which you can access the installation's web directory. Requires a trailing '/'
#   e.g. http://localhost/cookingspecial/

# Note: You can also specify this as argument 2 (see Usage), in which case this value will be overridden.
INSTALL_WWW_DIR="http://cubist.cs.washington.edu/projects/09sp/cse403/cookingspecial/daily/website/www/"

# Note: You can also specify this as argument 1, in which case this value will be overridden.
SRC_DIR="./src"

####### END CHANGE VARIABLES #######

function usage {
    echo "Usage is as:"
    echo "	./unittest.sh -h"
    echo "	./unittest.sh SRC_DIR INSTALL_WWW_DIR"
    echo "		(SRC_DIR equates to the /src of the source directory and uses relative paths)"
}
# Check parameters
if [ $# -eq 0 ]; then
	echo "No parameters entered. Using default values (edit unittest.sh to change)"
elif [ $1 = "-h" ]; then
	usage
	exit 0;
elif [ $# -eq 1 ]; then
	SRC_DIR="$1"
elif [ $# -eq 2 ]; then
	SRC_DIR="$1"
	INSTALL_WWW_DIR="$2"
else
	usage
	exit -1;
fi

echo "Using SRC_DIR="$SRC_DIR
echo "Using INSTALL_WWW_DIR=${INSTALL_WWW_DIR}"


####################################
# Run Unit Tests
####################################
echo "Running Backend Unit Tests"
links -dump -dump-width 150 $INSTALL_WWW_DIR/index.php?page=unittest&action=index

echo ""
echo "Running Parser Unit Tests"
bash $SRC_DIR/parser/tests/allrecipes_test.sh

echo ""
echo "Running Frontend Unit Tests"
echo "If you get errors, please check that jmeter is on your PATH per the test documentation"
jmeter -n -t $SRC_DIR/website/jmeter/search.jmx -Jtype=recipe
jmeter -n -t $SRC_DIR/website/jmeter/search.jmx -Jtype=special
jmeter -n -t $SRC_DIR/website/jmeter/load.jmx
